@@ -96,9 +96,9 @@ extern int checkforpartrejoin(struct channel *, char *, char *);
 extern int checkforaction(struct channel *, char *, char *, int);
 extern int delchankey(struct channel *);
 extern int delchanlimit(struct channel *);
-extern int delpermban(struct channel *, char *);
-extern int delnickbk(struct channel *, char *);
-extern int delwordbk(struct channel *, char *);
+extern int delpermbans(struct channel *, char *, int);
+extern int delnickbks(struct channel *, char *, int);
+extern int delwordbks(struct channel *, char *, int);
 extern int uptime(time_t *, time_t *);
 extern int deladmin(char *);
 extern int deladminmask(char *, char *);
@@ -200,6 +200,7 @@ extern void sendchannelnotice(struct channel *, int, char *);
 extern void addcommand(struct channel *, char *, int, char *, char *, char *);
 extern void delcommand(struct channel *, char *, int, char *, char *, char *);
 extern void editcommand(struct channel *, char *, int, char *, char *, char *);
+extern void extcommand(struct channel *, char *, int, char *, char *, char *);
 extern void listcommand(struct channel *, char *, int, char *, char *, char *);
 extern void logoffcommand(struct channel *, char *, int, char *, char *, char *);
 extern void logoncommand(struct channel *, char *, int, char *, char *, char *);
@@ -238,3 +239,4 @@ extern void timed_del(struct timed *);
 extern void mmode_del(struct channel *, struct mmode *);
 extern void validateflags(char *, char *, int);
 extern void resetfloodcounters(struct channel *, char *);
+extern void resetcommand(struct channel *, char *, int, char *, char *, char *);
