@@ -168,6 +168,8 @@ enum WHICHCOMMAND_RETURN_VALUES {
 	OER_WHICHCOMMAND_CLEARBANS,
 	OER_WHICHCOMMAND_CYCLE,
 	OER_WHICHCOMMAND_BSTATS,
+	OER_WHICHCOMMAND_EXT,
+	OER_WHICHCOMMAND_RESET,
 	OER_WHICHCOMMAND_INVALID
 };
 
@@ -361,7 +363,7 @@ enum OER_FLAGS_TYPE {
 #define OER_SERVER_IS_STONED "stoned server"
 #define OER_INTERNAL_DYNAMIC_ADMIN "*INTDYN*"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-57, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-58, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
