@@ -1119,8 +1119,8 @@ void parseirc(char *serveroutput)
                         return;
                 }
                 if(haschanflags(this, "t")) {
-			/* only allow topic changes through us */
-			if(!isme(temp_nick)) {
+			/* only allow topic changes through us and services */
+			if(!isme(temp_nick) && !isq(temp_nick) && !isservice(temp_nick)) {
 				this->topic_change = 1;
 			}
 		}
@@ -2805,6 +2805,60 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                 snprintf(outstring, WRITE_BUFFER_LENGTH, "%d %s (%d %s), %d %s (%d %s), %d channel %s and %d %s", numofadmins, (numofadmins == 1) ? "admin" : "admins", numofadminmasks, (numofadminmasks == 1) ? "mask" : "masks", numofusers, (numofusers == 1) ? "user" : "users", numofusermasks, (numofusermasks == 1) ? "mask" : "masks", numofchanusers, (numofchanusers == 1) ? "user" : "users", numofchans, (numofchans == 1) ? "channel" : "channels");
 		sendreply((tochan) ? channel : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
                 return;
+	case OER_WHICHCOMMAND_EXT:
+#ifdef DEBUG
+		oer_debug(OER_DEBUG_INFO, "parsecommand->EXT\n");
+#endif
+                if(!strlen(restptr)) {
+                        return;
+                }
+		/* channel is optional */
+		this = getchptr(channel);
+		proceed = (isopa(userhost)) ? 1 : 0;
+		if(tochan) {
+			if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+				return;
+			}
+			if(isatleastopnow(this, nick, userhost)) {
+				proceed = 1;
+			}
+			/* check if "s" flag set */
+			if(haschanflags(this, "s")) {
+				proceed = 1;
+			}
+		} else {
+			for(that = mystate->channels; that != NULL && !proceed; that = that->next) {
+				if(haschanflags(that, "U") && !isatleastop(that, nick, userhost)) {
+					continue;
+				}
+				if(isatleastopnow(that, nick, userhost)) {
+					proceed = 1;
+				}
+			}
+		}
+		if(!proceed) {
+			return;
+		}
+		extcommand(this, (tochan) ? this->name : nick, tochan, nick, userhost, restptr);
+		return;
+	case OER_WHICHCOMMAND_RESET:
+#ifdef DEBUG
+		oer_debug(OER_DEBUG_INFO, "parsecommand->RESET\n");
+#endif
+		if((this = getchptr(channel)) == NULL) {
+			return;
+		}
+		if(!strlen(restptr)) {
+			return;
+		}
+		if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+			return;
+		}
+		if(!isatleastopnow(this, nick, userhost)) {
+			return;
+		}
+		resetcommand(this, (tochan) ? this->name : nick, tochan, nick, userhost, restptr);
+		return;
         case OER_WHICHCOMMAND_INVALID:
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->invalid or malformed command %s\n", command);
