@@ -41,9 +41,11 @@ do
 done
 
 $ECHO "Install tool is $INSTALL (params: $PARAMS)"
-$ECHO "Installing oer binary into $INSTALLTO (change with configure)"
+$ECHO ""
+readln "Install oer binary into [$INSTALLTO] " "$INSTALLTO"
+INSTALLTO=$ans
 if [ ! -d $INSTALLTO ]; then
-    $ECHO "  Creating directory $INSTALLTO"
+    $ECHO "Creating directory $INSTALLTO"
     mkdir -p $INSTALLTO
 fi
 $ECHO "  Installing oer binary into directory $INSTALLTO"
@@ -82,7 +84,7 @@ if [ "$CREATECONF" = "Y" -o "$CREATECONF" = "y" ]; then
     VIRTHOST=$ans
     readln "Please specify optional proxy setup string [] " ""
     PROXYSETUP=$ans
-    readln "Please specify default IRC server to connect to [irc1.equnet.org] " "irc1.equnet.org"
+    readln "Please specify default IRC server to connect to [irc.equnet.org] " "irc.equnet.org"
     SERVER=$ans
     readln "Please specify port [6667] " "6667"
     PORT=$ans
@@ -195,14 +197,9 @@ if [ "$CREATECONF" = "Y" -o "$CREATECONF" = "y" ]; then
 	$ECHO "  oer configuration installed succesfully"
     fi
 fi
+
+$ECHO ""
+$ECHO "  Type \"./oer\" in $INSTALLTO to start oer"
+$ECHO ""
+
 exit 0
-
-
-
-
-
-
-
-
-
-
